@@ -39,7 +39,7 @@ sub start {
 
 ## Wait for the server to respond with data and a status.
 ##
-## @return [response data, status]
+## @return (response data, status)
 
 sub wait {
 	my $self  = shift;
@@ -49,7 +49,9 @@ sub wait {
             Grpc::Constants::GRPC_OP_RECV_STATUS_ON_CLIENT() => true,
    	);
 
-	return $self->deserializeResponse($event->{message},$event->{status});
+    return wantarray
+    ? ($self->deserializeResponse($event->{message}), $event->{status})
+    : $self->deserializeResponse($event->{message});
 }
 
 1;
